This crate contains kube-rs compatible bindings for Kubernetes custom resources for the extensions.kubeblocks.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
extensions.kubeblocks.io/v1alpha1
Addon